summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka/nodeenhancer.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/parts/kafka/nodeenhancer.h')
-rw-r--r--quanta/parts/kafka/nodeenhancer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/quanta/parts/kafka/nodeenhancer.h b/quanta/parts/kafka/nodeenhancer.h
index 376379f1..22737082 100644
--- a/quanta/parts/kafka/nodeenhancer.h
+++ b/quanta/parts/kafka/nodeenhancer.h
@@ -45,10 +45,10 @@ public:
* The DOM::Node must be built before calling this
* function.
* @param node The Node we want to enhance.
* @param parentDNode the parent DOM::Node of the root DOM::Node of node.
* @param nextDNode the DOM::Node next to the root DOM::Node of node.
*/
- virtual bool enhanceNode(Node *node, DOM::Node parentDNode, DOM::Node nextDNode) = 0;
+ virtual bool enhanceNode(Node *node, DOM::Node tqparentDNode, DOM::Node nextDNode) = 0;
/**
* This function apply some modifications once the whole DOM::Node tree is built.
@@ -45,10 +45,10 @@ public:
* function.
* @param node The Node we want to enhance.
- * @param parentDNode the parent DOM::Node of the root DOM::Node of node.
+ * @param tqparentDNode the tqparent DOM::Node of the root DOM::Node of node.
* @param nextDNode the DOM::Node next to the root DOM::Node of node.
*/